Contributing & Citation
***********************

Contributing guide
------------------

We welcome any contribution to the skpro project. Please read our `contribution guide <https://github.com/alan-turing-institute/skpro/blob/master/CONTRIBUTING.md>`_ on Github.

Cite skpro
----------

If you use skpro in a scientific publication, we would appreciate citations to the following paper:

.. include:: ../CITATION.rst